@@ -26,6 +26,7 @@ import subprocess
 import tempfile
 from Namcap.util import is_elf, script_type
 from Namcap.ruleclass import *
+import Namcap.tags
 
 pkgcache = {}
 
@@ -59,12 +60,14 @@ def getprovides(depends, provides):
 
 		if pac != None and "provides" in pac and pac["provides"] != None:
 			provides[i] = pac["provides"]
+		else:
+			provides[i] = []
 
 def analyze_depends(pkginfo):
 	errors, warnings, infos = [], [], []
 
 	# compute needed dependencies + recursive
-	dependlist = set(pkginfo.detected_deps)
+	dependlist = set(pkginfo.detected_deps.keys())
 	indirectdependlist = getcovered(dependlist)
 	for i in indirectdependlist:
 		infos.append(("dependency-covered-by-link-dependence %s", i))
@@ -86,9 +89,7 @@ def analyze_depends(pkginfo):
 	# Get the provides so we can reference them later
 	# smartprovides : depend => (packages provided by depend)
 	smartprovides = {}
-	getprovides(explicitdepend, smartprovides)
-	getprovides(implicitdepend, smartprovides)
-	getprovides(optdepend, smartprovides)
+	getprovides(smartdepend, smartprovides)
 
 	# The set of all provides for detected dependencies
 	allprovides = set()
@@ -103,27 +104,23 @@ def analyze_depends(pkginfo):
 		# if the dependency is satisfied
 		if i in pkgbuild_depend:
 			continue
-		# if the dependency is actually provided
-		found = False
-		for depend, provides in smartprovides.items():
-			if i in provides and depend in pkgbuild_depend:
-				found = True
-				continue
-		if found:
+		# if the dependency is pulled as a provider for some explicit dep
+		if len(set(smartprovides[i]) & pkgbuild_depend) > 0:
 			continue
+		# compute dependency reason
+		reasons = pkginfo.detected_deps[i]
+		reason_strings = [Namcap.tags.format_message(reason) for reason in reasons]
+		reason = ', '.join(reason_strings)
 		# still not found, maybe it is specified as optional
 		if i in optdepend:
-			warnings.append(("dependency-detected-but-optional %s", i))
+			warnings.append(("dependency-detected-but-optional %s (%s)", (i, reason)))
 			continue
-		# maybe, worse, it is provided by an optdepend
-		for depend, provides in smartprovides.items():
-			if i in provides and depend in optdepend:
-				found = True
-		if found:
-			warnings.append(("dependency-detected-but-optional %s", i))
+		# maybe, it is pulled as a provider for an optdepend
+		if len(set(smartprovides[i]) & optdepend) > 0:
+			warnings.append(("dependency-detected-but-optional %s (%s)", (i, reason)))
 			continue
 		# now i'm pretty sure i didn't find it.
-		errors.append(("dependency-detected-not-included %s", i))
+		errors.append(("dependency-detected-not-included %s (%s)", (i, reason)))
 
 	for i in pkginfo["depends"]:
 		# a needed dependency is superfluous it is implicitly satisfied
@@ -131,11 +128,9 @@ def analyze_depends(pkginfo):
 			warnings.append(("dependency-already-satisfied %s", i))
 		# a dependency is unneeded if:
 		#   it is not in the depends as we see them
-		#   it's not a provider for some needed dependency
-		elif i not in needed_depend:
-			needed_provides = set(smartprovides.get(i, [])) & needed_depend
-			if len(needed_provides) == 0:
-				warnings.append(("dependency-not-needed %s", i))
+		#   it does not pull some needed dependency which provides it
+		elif i not in needed_depend and i not in allprovides:
+			warnings.append(("dependency-not-needed %s", i))
 	infos.append(("depends-by-namcap-sight depends=(%s)", ' '.join(smartdepend) ))
 
 	return errors, warnings, infos
