@@ -53,10 +53,13 @@ package() {
 				Namcap.rules.hicoloricons.package
 				)
 		e, w, i = Namcap.depends.analyze_depends(pkg)
-		self.assertEqual(pkg.detected_deps, ["hicolor-icon-theme"])
+		self.assertEqual(pkg.detected_deps, {
+			"hicolor-icon-theme": [('hicolor-icon-theme-needed-for-hicolor-dir',())]
+			})
 		self.assertEqual(set(r.errors + e), set([
-			('dependency-detected-not-included %s',
-				'hicolor-icon-theme'),
+			('dependency-detected-not-included %s (%s)',
+			 ('hicolor-icon-theme', 'needed for hicolor theme hierarchy')
+			),
 			("hicolor-icon-cache-not-updated", ())
 		]))
 		self.assertEqual(r.warnings + w, [])
@@ -93,7 +96,9 @@ package() {
 				Namcap.rules.hicoloricons.package
 				)
 		e, w, i = Namcap.depends.analyze_depends(pkg)
-		self.assertEqual(pkg.detected_deps, ["hicolor-icon-theme"])
+		self.assertEqual(pkg.detected_deps, {
+			"hicolor-icon-theme": [('hicolor-icon-theme-needed-for-hicolor-dir',())]
+			})
 		self.assertEqual(r.errors + e, [
 			("hicolor-icon-cache-not-updated", ())
 			])
